//
// C++ Interface: %{MODULE}
//
// Description: 
//
//
// Author: %{AUTHOR} <%{EMAIL}>, (C) %{YEAR}
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KPGSETTABLESPACEWIZARD_H
#define KPGSETTABLESPACEWIZARD_H

#include "kpg3stepswizard.h"

class KPGTablespacesFolder;

/**
  * Set tablespace Wizard
  *
  * @author Lumir Vanek
  */
class KPGSetTablespaceWizard : public KPG3StepsWizard
{
Q_OBJECT
public:
    KPGSetTablespaceWizard(QWidget *parent, const char *name, KPGTablespacesFolder *, const char *, const QString &, const QString &);
    ~KPGSetTablespaceWizard();

protected:
    virtual void showPage(QWidget *);

protected:
  	QString m_strObjectTypeName; // TABLE, INDEX ...
  	QString m_strNamespaceObjectName; // schema qualified object name
      
protected slots:
    virtual void languageChange(); 
};

#endif
